package com.zd.chemical.service.impl;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.zd.chemical.mapper.ActHxpapplyDetailMapper;
import com.zd.chemical.domain.ActHxpapplyDetail;
import com.zd.chemical.service.IActHxpapplyDetailService;

/**
 * 化学品申购详情Service业务层处理
 *
 * @author zd
 * @date 2022-08-17
 */
@Service
public class ActHxpapplyDetailServiceImpl implements IActHxpapplyDetailService
{
    @Autowired
    private ActHxpapplyDetailMapper actHxpapplyDetailMapper;

    /**
     * 查询化学品申购详情
     *
     * @param id 化学品申购详情主键
     * @return 化学品申购详情
     */
    @Override
    public ActHxpapplyDetail selectActHxpapplyDetailById(Long id)
    {
        return actHxpapplyDetailMapper.selectActHxpapplyDetailById(id);
    }

    /**
     * 查询化学品申购详情列表
     *
     * @param actHxpapplyDetail 化学品申购详情
     * @return 化学品申购详情
     */
    @Override
    public List<ActHxpapplyDetail> selectActHxpapplyDetailList(ActHxpapplyDetail actHxpapplyDetail)
    {
        return actHxpapplyDetailMapper.selectActHxpapplyDetailList(actHxpapplyDetail);
    }

    @Override
    public List<ActHxpapplyDetail> getListByIds(List<Long> ids){
        if (ids.isEmpty()){
            new ArrayList <>();
        }
        return actHxpapplyDetailMapper.getListByIds(ids);
    }

    /**
     * 新增化学品申购详情
     *
     * @param actHxpapplyDetail 化学品申购详情
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertActHxpapplyDetail(ActHxpapplyDetail actHxpapplyDetail)
    {
        return actHxpapplyDetailMapper.insertActHxpapplyDetail(actHxpapplyDetail);
    }

    /**
     * 修改化学品申购详情
     *
     * @param actHxpapplyDetail 化学品申购详情
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateActHxpapplyDetail(ActHxpapplyDetail actHxpapplyDetail)
    {
        return actHxpapplyDetailMapper.updateActHxpapplyDetail(actHxpapplyDetail);
    }

    /**
     * 批量删除化学品申购详情
     *
     * @param ids 需要删除的化学品申购详情主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteActHxpapplyDetailByIds(Long[] ids)
    {
        return actHxpapplyDetailMapper.deleteActHxpapplyDetailByIds(ids);
    }

    /**
     * 删除化学品申购详情信息
     *
     * @param id 化学品申购详情主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteActHxpapplyDetailById(Long id)
    {
        return actHxpapplyDetailMapper.deleteActHxpapplyDetailById(id);
    }

}
