package com.zd.chemical.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.chemical.domain.ActHxpapplyDetail;
import com.zd.chemical.service.IActHxpapplyDetailService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 化学品申购详情Controller
 *
 * @author zd
 * @date 2022-08-17
 */
@RestController
@Api(tags = "【化学品申购详情】")
@RequestMapping("/hxpapplyDetail")
public class ActHxpapplyDetailController extends BaseController<ActHxpapplyDetail>
{
    @Autowired
    private IActHxpapplyDetailService actHxpapplyDetailService;

    /**
     * 查询化学品申购详情列表
     */
//    @PreAuthorize(hasPermi = "laboratory:detail:list")
    @GetMapping("/list")
    @ApiOperation(value = "查询化学品申购详情列表")
    public TableDataInfo<ActHxpapplyDetail> list(ActHxpapplyDetail actHxpapplyDetail)
    {
        startPage();
        List<ActHxpapplyDetail> list = actHxpapplyDetailService.selectActHxpapplyDetailList(actHxpapplyDetail);
        return getDataTable(list);
    }

    /**
     * 导出化学品申购详情列表
     */
    @ApiOperation(value = "导出化学品申购详情列表")
//    @PreAuthorize(hasPermi = "laboratory:detail:export")
    @Log(title = "化学品申购详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ActHxpapplyDetail actHxpapplyDetail) throws IOException
    {
        List<ActHxpapplyDetail> list = actHxpapplyDetailService.selectActHxpapplyDetailList(actHxpapplyDetail);
        ExcelUtil<ActHxpapplyDetail> util = new ExcelUtil<ActHxpapplyDetail>(ActHxpapplyDetail.class);
        util.exportExcel(response, list, "化学品申购详情数据");
    }

    /**
     * 获取化学品申购详情详细信息
     */
    @ApiOperation(value = "获取化学品申购详情详细信息")
//    @PreAuthorize(hasPermi = "laboratory:detail:query")
    @GetMapping(value = "/{id}")
    public ResultData<ActHxpapplyDetail> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(actHxpapplyDetailService.selectActHxpapplyDetailById(id));
    }

    /**
     * 新增化学品申购详情
     */
    @ApiOperation(value = "新增化学品申购详情")
//    @PreAuthorize(hasPermi = "laboratory:detail:add")
    @Log(title = "化学品申购详情", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody ActHxpapplyDetail actHxpapplyDetail)
    {
        return ResultData.result(actHxpapplyDetailService.insertActHxpapplyDetail(actHxpapplyDetail));
    }

    /**
     * 修改化学品申购详情
     */
    @ApiOperation(value = "修改化学品申购详情")
//    @PreAuthorize(hasPermi = "laboratory:detail:edit")
    @Log(title = "化学品申购详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody ActHxpapplyDetail actHxpapplyDetail)
    {
        return  ResultData.result(actHxpapplyDetailService.updateActHxpapplyDetail(actHxpapplyDetail));
    }

    /**
     * 删除化学品申购详情
     */
    @ApiOperation(value = "删除化学品申购详情")
//    @PreAuthorize(hasPermi = "laboratory:detail:remove")
    @Log(title = "化学品申购详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(actHxpapplyDetailService.deleteActHxpapplyDetailByIds(ids));
    }
}
